@@ -11,6 +11,7 @@ import aiohttp
 import requests
 from loguru import logger
 from PIL import Image
+from sparrow.decorators.core import async_retry
 
 # 兼容不同版本的PIL
 try:
@@ -283,6 +284,15 @@ def decode_base64_to_bytes(base64_string):
         raise ValueError(f"无法将base64字符串解码为字节数据: {e!s}")
 
 
+@async_retry(retry_times=3, retry_delay=0.3)
+async def _get_image_from_http(session, image_source):
+    async with session.get(image_source) as response:
+        response.raise_for_status()
+        content = await response.read()
+        image = Image.open(BytesIO(content))
+        return image
+
+
 async def get_pil_image(
     image_source,
     session: aiohttp.ClientSession = None,
@@ -338,17 +348,13 @@ async def get_pil_image(
                 close_session = True
                 
             try:
-                async with session.get(image_source) as response:
-                    response.raise_for_status()
-                    content = await response.read()
-                    image = Image.open(BytesIO(content))
-                    
-                    # 保存到缓存
-                    if use_cache:
-                        try:
-                            save_image_with_format(image, cache_path)
-                        except Exception as e:
-                            logger.warning(f"保存图片到缓存失败: {e}")
+                image = await _get_image_from_http(session, image_source)
+                # 保存到缓存
+                if use_cache:
+                    try:
+                        save_image_with_format(image, cache_path)
+                    except Exception as e:
+                        logger.warning(f"保存图片到缓存失败: {e}")
                     
                     return image
             finally:
