@@ -15,7 +15,10 @@ from sparrow.vllm.client.image_processor import (
     decode_base64_to_file,
     decode_base64_to_bytes,
     DEFAULT_CACHE_DIR,
+    get_pil_image,
+    LANCZOS,
 )
+# 兼容不同版本的PIL
 from sparrow.vllm.client.messages_processor import (
     process_content_recursive,
     messages_preprocess,
@@ -179,6 +182,41 @@ class ImageProcessor:
             return_with_mime=return_with_mime
         )
         return result
+
+    async def get_pil_image(self, image_source: str, max_width: Optional[int] = None, max_height: Optional[int] = None, max_pixels: Optional[int] = None, use_cache: bool = True, cache_dir: str = DEFAULT_CACHE_DIR, force_refresh: bool = False) -> Image.Image:
+        """获取图像，支持多种输入源和大小限制
+        
+        Args:
+            image_source: 图像源，可以是文件路径、URL
+            use_cache: 是否使用缓存
+            cache_dir: 缓存目录
+            force_refresh: 是否强制刷新缓存
+        Returns:
+            PIL.Image对象
+        """
+        session = await self._ensure_session()
+        image = await get_pil_image(image_source, session, use_cache=use_cache, cache_dir=cache_dir, force_refresh=force_refresh)
+
+        # Resize image based on provided constraints
+        if max_width and max_height:
+            # Use thumbnail to maintain aspect ratio while fitting within max dimensions
+            image.thumbnail((max_width, max_height), LANCZOS)
+        elif max_width:
+            # Use thumbnail with unlimited height
+            image.thumbnail((max_width, float("inf")), LANCZOS)
+        elif max_height:
+            # Use thumbnail with unlimited width
+            image.thumbnail((float("inf"), max_height), LANCZOS)
+
+        # Handle max_pixels constraint (after other resizing to avoid unnecessary work)
+        if max_pixels and (image.width * image.height > max_pixels):
+            # Calculate the ratio needed to get to max_pixels
+            ratio = (max_pixels / (image.width * image.height)) ** 0.5
+            # Use thumbnail to maintain aspect ratio
+            target_width = int(image.width * ratio)
+            target_height = int(image.height * ratio)
+            image.thumbnail((target_width, target_height), LANCZOS)
+        return image
     
     async def encode_image(
         self, 
